Changes
=======

0.3.4 2013-03-23
----------------
- Compatible with Python 3
- Remove some confusing default options for JSLint

0.3.3 2011-12-01
----------------
- Use status code to detect if the file was valid instead of parsing the
  output from the node script
- Fix bug in the hook interface

0.3.2 2011-11-17
----------------
- Fix bug in setup.py, wrong directive and wrong entry point

0.3.1 2011-11-16
----------------
- Rename the module to avoid collisions with the jslint python wrapper project

0.3 2011-11-16
--------------
- Simplify the module by moving the main file into the root directory
- Remove the reformat function

